@@ -105,16 +105,22 @@ def setContainerItems(graph, node, predicate, values, newtype=RDF.Seq):
 # Instances of FocusedGraph have a specified "focus node".
 
 class FocusedGraph(Graph):
-    def __init__(self, focus=None, **kwargs):
+    def __init__(self, focus=None, source=None, focus_class=None, **kwargs):
         super().__init__(**kwargs)
-        self._focus = focus or self.findFocus(**kwargs)
+        if source:
+            self.parse(source)
+        self._focus = focus or self.findFocus(focus_class=focus_class, **kwargs)
 
     @property
     def focus(self):
         return self._focus
 
-    def findFocus(self, **kwargs):
-        raise NotImplementedError()
+    def findFocus(self, focus_class=None, **kwargs):
+        if focus_class:
+            focus = next(self.triples((None, RDF.type, focus_class)), None)
+            if focus:
+                return focus[0]
+        raise ValueError("No focus found")
 
     def getvalue(self, predicate):
         return getvalue(self, self._focus, predicate)
